@@ -296,18 +296,6 @@ meta_parse_options (int *argc, char ***argv,
       N_("Make X calls synchronous"),
       NULL
     },
-    {
-      "composite", 'c', COMPOSITE_OPTS_FLAGS, G_OPTION_ARG_NONE,
-      &my_args.composite,
-      N_("Turn compositing on"),
-      NULL
-    },
-    {
-      "no-composite", 0, COMPOSITE_OPTS_FLAGS, G_OPTION_ARG_NONE,
-      &my_args.no_composite,
-      N_("Turn compositing off"),
-      NULL
-    },
     {
       "no-force-fullscreen", 0, COMPOSITE_OPTS_FLAGS, G_OPTION_ARG_NONE,
       &my_args.no_force_fullscreen,
@@ -454,7 +442,7 @@ sigterm_handler (int signum)
 {
   if (sigterm_pipe_fds[1] >= 0)
     {
-      int dummy;
+      int G_GNUC_UNUSED dummy;
 
       dummy = write (sigterm_pipe_fds[1], "", 1);
       close (sigterm_pipe_fds[1]);
@@ -623,9 +611,6 @@ main (int argc, char **argv)
 
   g_option_context_free (ctx);
 
-  /* must be after UI init so we can override GDK handlers */
-  meta_errors_init ();
-
   /* Load prefs */
   meta_prefs_init ();
   meta_prefs_add_listener (prefs_changed_callback, NULL);
@@ -708,9 +693,6 @@ main (int argc, char **argv)
   g_free (meta_args.display_name);
   g_free (meta_args.client_id);
 
-  if (meta_args.composite || meta_args.no_composite)
-    meta_prefs_set_compositing_manager (meta_args.composite);
-
   if (meta_args.no_force_fullscreen)
     meta_prefs_set_force_fullscreen (FALSE);
 
