@@ -36,9 +36,6 @@
 #include <gtk/gtk.h>
 #include <math.h>
 
-#include "gtk-compat.h"
-#include "gdk2-drawing-utils.h"
-
 #define OUTSIDE_SELECT_RECT 2
 #define INSIDE_SELECT_RECT 2
 
@@ -74,24 +71,13 @@ static GtkWidget* selectable_workspace_new (MetaWorkspace *workspace);
 static void       select_workspace         (GtkWidget *widget);
 static void       unselect_workspace       (GtkWidget *widget);
 
-#ifdef USE_GTK3
 static gboolean
 outline_window_draw (GtkWidget *widget,
                      cairo_t   *cr,
                      gpointer   data)
 {
-#else /* !USE_GTK3 */
-static gboolean
-outline_window_expose (GtkWidget      *widget,
-                       GdkEventExpose *event,
-                       gpointer        data)
-{
-  cairo_t *cr = gdk_cairo_create (event->window);
-#endif /* !USE_GTK3 */
-
   MetaTabPopup *popup;
   TabEntry *te;
-  GtkStyle *style;
   
   popup = data;
 
@@ -99,10 +85,9 @@ outline_window_expose (GtkWidget      *widget,
     return FALSE;
 
   te = popup->current_selected_entry;
-  style = gtk_widget_get_style (widget);
 
   cairo_set_line_width (cr, 1.0);
-  gdk_cairo_set_source_color (cr, &style->white);
+  cairo_set_source_rgb (cr, 1.0, 1.0, 1.0);
 
   cairo_rectangle (cr,
                    0.5, 0.5,
@@ -116,10 +101,6 @@ outline_window_expose (GtkWidget      *widget,
                    te->inner_rect.height + 1);
   cairo_stroke (cr);
 
-#ifndef USE_GTK3
-  cairo_destroy (cr);
-#endif
-
   return FALSE;
 }
 
@@ -260,13 +241,8 @@ meta_ui_tab_popup_new (const MetaTabEntry *entries,
   gtk_widget_set_app_paintable (popup->outline_window, TRUE);
   gtk_widget_realize (popup->outline_window);
 
-#ifdef USE_GTK3
   g_signal_connect (G_OBJECT (popup->outline_window), "draw",
                     G_CALLBACK (outline_window_draw), popup);
-#else
-  g_signal_connect (G_OBJECT (popup->outline_window), "expose_event",
-                    G_CALLBACK (outline_window_expose), popup);
-#endif
   
   popup->window = gtk_window_new (GTK_WINDOW_POPUP);
 
@@ -499,6 +475,10 @@ display_entry (MetaTabPopup *popup,
 
   if (popup->outline)
     {
+      cairo_region_t *region;
+      cairo_region_t *inner_region;
+      GdkRGBA black = { 0.0, 0.0, 0.0, 1.0 };
+
       window = gtk_widget_get_window (popup->outline_window);
 
       /* Do stuff behind gtk's back */
@@ -514,42 +494,20 @@ display_entry (MetaTabPopup *popup,
                               te->rect.x, te->rect.y,
                               te->rect.width, te->rect.height);
   
-      gdk_window_set_background (window,
-                                 &gtk_widget_get_style (popup->outline_window)->black);
-  
-#if GTK_CHECK_VERSION (2, 90, 8) /* gtk3 */
-      {
-        cairo_region_t *region;
-        cairo_region_t *inner_region;
+      gdk_window_set_background_rgba (window, &black);
 
-        region = cairo_region_create_rectangle (&rect);
-        inner_region = cairo_region_create_rectangle (&te->inner_rect);
-        cairo_region_subtract (region, inner_region);
-        cairo_region_destroy (inner_region);
 
-        gdk_window_shape_combine_region (window,
-                                         region,
-                                         0, 0);
+      region = cairo_region_create_rectangle (&rect);
+      inner_region = cairo_region_create_rectangle (&te->inner_rect);
+      cairo_region_subtract (region, inner_region);
+      cairo_region_destroy (inner_region);
 
-        cairo_region_destroy (region);
-      }
-#else /* gtk2 */
-      {
-        GdkRegion *region;
-        GdkRegion *inner_region;
+      gdk_window_shape_combine_region (window,
+                                       region,
+                                       0, 0);
 
-        region = gdk_region_rectangle (&rect);
-        inner_region = gdk_region_rectangle (&te->inner_rect);
-        gdk_region_subtract (region, inner_region);
-        gdk_region_destroy (inner_region);
-
-        gdk_window_shape_combine_region (window,
-                                         region,
-                                         0, 0);
-
-        gdk_region_destroy (region);
-      }
-#endif /* gtk2 */
+      cairo_region_destroy (region);
+    
 
       /* This should piss off gtk a bit, but we don't want to raise
        * above the tab popup.  So, instead of calling gtk_widget_show,
@@ -693,13 +651,8 @@ unselect_image (GtkWidget *widget)
 }
 
 static void     meta_select_image_class_init   (MetaSelectImageClass *klass);
-#if USE_GTK3
 static gboolean meta_select_image_draw         (GtkWidget            *widget,
                                                 cairo_t              *cr);
-#else
-static gboolean meta_select_image_expose_event (GtkWidget            *widget,
-                                                GdkEventExpose       *event);
-#endif
 
 static GtkImageClass *parent_class;
 
@@ -738,14 +691,9 @@ meta_select_image_class_init (MetaSelectImageClass *klass)
 
   widget_class = GTK_WIDGET_CLASS (klass);
   
-#if USE_GTK3
   widget_class->draw = meta_select_image_draw;
-#else
-  widget_class->expose_event = meta_select_image_expose_event;
-#endif
 }
 
-#if USE_GTK3
 static gboolean
 meta_select_image_draw (GtkWidget *widget,
                         cairo_t   *cr)
@@ -753,27 +701,13 @@ meta_select_image_draw (GtkWidget *widget,
   GtkAllocation allocation;
 
   gtk_widget_get_allocation (widget, &allocation);
-#else /* !USE_GTK3 */
-static gboolean
-meta_select_image_expose_event (GtkWidget      *widget,
-                                GdkEventExpose *event)
-{
-  GtkAllocation allocation;
-  cairo_t *cr = gdk_cairo_create (event->window);
-
-  gdk_cairo_region (cr, event->region);
-  cairo_clip (cr);
-  gtk_widget_get_allocation (widget, &allocation);
-  cairo_translate (cr, allocation.x, allocation.y);
-#endif
 
   if (META_SELECT_IMAGE (widget)->selected)
     {
       GtkMisc *misc;
       GtkRequisition requisition;
-      GtkStyle *style;
-      GtkStateType state;
-      GdkWindow *window;
+      GtkStyleContext *context;
+      GdkRGBA color;
       int x, y, w, h;
       gint xpad, ypad;
       gfloat xalign, yalign;
@@ -793,12 +727,15 @@ meta_select_image_expose_event (GtkWidget      *widget,
       w = requisition.width - OUTSIDE_SELECT_RECT * 2 - 1;
       h = requisition.height - OUTSIDE_SELECT_RECT * 2 - 1;
 
-      window = gtk_widget_get_window (widget);
-      style = gtk_widget_get_style (widget);
-      state = gtk_widget_get_state (widget);
+      context = gtk_widget_get_style_context (widget);
+
+      gtk_style_context_set_state (context,
+                                   gtk_widget_get_state_flags (widget));
+
+      gtk_style_context_lookup_color (context, "color", &color);
 
       cairo_set_line_width (cr, 2.0);
-      gdk_cairo_set_source_color (cr, &style->fg[state]);
+      cairo_set_source_rgb (cr, color.red, color.green, color.blue);
 
       cairo_rectangle (cr, x, y, w + 1, h + 1);
       cairo_stroke (cr);
@@ -806,13 +743,7 @@ meta_select_image_expose_event (GtkWidget      *widget,
       cairo_set_line_width (cr, 1.0);
     }
 
-#ifdef USE_GTK3
   return GTK_WIDGET_CLASS (parent_class)->draw (widget, cr);
-#else
-  cairo_destroy (cr);
-
-  return GTK_WIDGET_CLASS (parent_class)->expose_event (widget, event);
-#endif /* !USE_GTK3 */
 }
 
 #define META_TYPE_SELECT_WORKSPACE   (meta_select_workspace_get_type ())
@@ -876,13 +807,8 @@ unselect_workspace (GtkWidget *widget)
 
 static void meta_select_workspace_class_init (MetaSelectWorkspaceClass *klass);
 
-#if USE_GTK3
 static gboolean meta_select_workspace_draw         (GtkWidget      *widget,
                                                     cairo_t        *cr);
-#else
-static gboolean meta_select_workspace_expose_event (GtkWidget      *widget,
-                                                    GdkEventExpose *event);
-#endif
 
 GType
 meta_select_workspace_get_type (void)
@@ -920,11 +846,7 @@ meta_select_workspace_class_init (MetaSelectWorkspaceClass *klass)
   
   widget_class = GTK_WIDGET_CLASS (klass);
   
-#if USE_GTK3
   widget_class->draw = meta_select_workspace_draw;
-#else
-  widget_class->expose_event = meta_select_workspace_expose_event;
-#endif
 }
 
 /**
@@ -961,22 +883,13 @@ meta_convert_meta_to_wnck (MetaWindow *window, MetaScreen *screen)
 }
 
 
-#ifdef USE_GTK3
 static gboolean
 meta_select_workspace_draw (GtkWidget *widget,
                             cairo_t   *cr)
 {
-#else /* !USE_GTK3 */
-static gboolean
-meta_select_workspace_expose_event (GtkWidget      *widget,
-                                    GdkEventExpose *event)
-{
-  cairo_t *cr = gdk_cairo_create (event->window);
-#endif /* !USE_GTK3 */
   MetaWorkspace *workspace;
   WnckWindowDisplayInfo *windows;
   GtkAllocation allocation;
-  GtkStyle *style;
   int i, n_windows;
   GList *tmp, *list;
 
@@ -1034,11 +947,18 @@ meta_select_workspace_expose_event (GtkWidget      *widget,
   
   if (META_SELECT_WORKSPACE (widget)->selected)
     {
-      style = gtk_widget_get_style (widget);
+      GtkStyleContext *context;
+      GdkRGBA color;
+
+      context = gtk_widget_get_style_context (widget);
+
+      gtk_style_context_set_state (context,
+                                   gtk_widget_get_state_flags (widget));
+
+      gtk_style_context_lookup_color (context, "color", &color);
 
-      gdk_cairo_set_source_color (cr,
-                                  &style->fg[gtk_widget_get_state (widget)]);
       cairo_set_line_width (cr, SELECT_OUTLINE_WIDTH);
+      cairo_set_source_rgb (cr, color.red, color.green, color.blue);
 
       cairo_rectangle (cr,
                        SELECT_OUTLINE_WIDTH / 2.0, SELECT_OUTLINE_WIDTH / 2.0,
@@ -1047,9 +967,5 @@ meta_select_workspace_expose_event (GtkWidget      *widget,
       cairo_stroke (cr);
     }
 
-#ifndef USE_GTK3
-  cairo_destroy (cr);
-#endif
-
   return TRUE;
 }
